@@ -23,7 +23,9 @@
 #include "akonadiconnection.h"
 #include "response.h"
 #include "storage/datastore.h"
+#include "storage/selectquerybuilder.h"
 #include "storage/transaction.h"
+#include "imapstreamparser.h"
 
 using namespace Akonadi;
 
@@ -36,11 +38,10 @@ Expunge::~Expunge()
 {
 }
 
-bool Expunge::handleLine( const QByteArray& )
+bool Expunge::parseStream()
 {
   Response response;
 
-  Location location = connection()->selectedLocation();
   DataStore *store = connection()->storageBackend();
   Transaction transaction( store );
 
@@ -55,23 +56,32 @@ bool Expunge::handleLine( const QByteArray& )
     return true;
   }
 
-  QList<PimItem> items = store->listPimItems( location, flag );
-  for ( int i = 0; i < items.count(); ++i ) {
-    if ( store->cleanupPimItem( items[ i ] ) ) {
-      response.setUntagged();
-      // IMAP protocol violation: should actually be the sequence number
-      response.setString( QByteArray::number( items[i].id() ) + " EXPUNGE" );
+  SelectQueryBuilder<PimItem> qb;
+  qb.addTable( PimItemFlagRelation::tableName() );
+  qb.addColumnCondition( PimItem::idFullColumnName(), Query::Equals, PimItemFlagRelation::leftFullColumnName() );
+  qb.addValueCondition( PimItemFlagRelation::rightFullColumnName(), Query::Equals, flag.id() );
 
-      emit responseAvailable( response );
-    } else {
-      response.setTag( tag() );
-      response.setError();
-      response.setString( "internal error" );
+  if ( qb.exec() ) {
+    const QList<PimItem> items = qb.result();
+    foreach ( const PimItem &item, items ) {
+      if ( store->cleanupPimItem( item ) ) {
+        response.setUntagged();
+        // IMAP protocol violation: should actually be the sequence number
+        response.setString( QByteArray::number( item.id() ) + " EXPUNGE" );
 
-      emit responseAvailable( response );
-      deleteLater();
-      return true;
+        emit responseAvailable( response );
+      } else {
+        response.setTag( tag() );
+        response.setError();
+        response.setString( "internal error" );
+
+        emit responseAvailable( response );
+        deleteLater();
+        return true;
+      }
     }
+  } else {
+    throw HandlerException( "Unable to execute query." );
   }
 
   if ( !transaction.commit() )
@@ -86,3 +96,5 @@ bool Expunge::handleLine( const QByteArray& )
 
   return true;
 }
+
+#include "expunge.moc"
