@@ -50,7 +50,8 @@ static const int itemQueryMimeTypeColumn = 3;
 static const int itemQueryResouceColumn = 4;
 static const int itemQuerySizeColumn = 5;
 static const int itemQueryDatetimeColumn = 6;
-
+static const int itemQueryCollectionIdColumn = 7;
+    
 static const int partQueryIdColumn = 0;
 static const int partQueryNameColumn = 1;
 static const int partQueryDataColumn = 2;
@@ -74,14 +75,14 @@ void Fetch::updateItemAccessTime()
   QueryBuilder qb( QueryBuilder::Update );
   qb.addTable( PimItem::tableName() );
   qb.updateColumnValue( PimItem::atimeColumn(), QDateTime::currentDateTime() );
-  addQueryConditions( qb );
+  ItemQueryHelper::scopeToQuery( mScope, connection(), qb );
   if ( !qb.exec() )
     qWarning() << "Unable to update item access time";
 }
 
 void Fetch::triggerOnDemandFetch()
 {
-  if ( mScope != Scope::None || connection()->selectedCollectionId() <= 0 )
+  if ( mScope.scope() != Scope::None || connection()->selectedCollectionId() <= 0 )
     return;
   Collection col = connection()->selectedCollection();
   // HACK: don't trigger on-demand syncing if the resource is the one triggering it
@@ -114,7 +115,7 @@ QueryBuilder Fetch::buildPartQuery( const QStringList &partList, bool allPayload
     if ( allAttrs )
       cond.addValueCondition( QString::fromLatin1( "substr( %1, 1, 4 )" ).arg( Part::nameFullColumnName() ), Query::Equals, QLatin1String( "ATR:" ) );
     partQuery.addCondition( cond );
-    addQueryConditions( partQuery );
+    ItemQueryHelper::scopeToQuery( mScope, connection(), partQuery );
     partQuery.addSortColumn( PimItem::idFullColumnName(), Query::Ascending );
   }
   return partQuery;
@@ -134,10 +135,11 @@ void Fetch::buildItemQuery()
   mItemQuery.addColumn( Resource::nameFullColumnName() );
   mItemQuery.addColumn( PimItem::sizeFullColumnName() );
   mItemQuery.addColumn( PimItem::datetimeFullColumnName() );
+  mItemQuery.addColumn( PimItem::collectionIdFullColumnName() );
   mItemQuery.addColumnCondition( PimItem::mimeTypeIdFullColumnName(), Query::Equals, MimeType::idFullColumnName() );
   mItemQuery.addColumnCondition( PimItem::collectionIdFullColumnName(), Query::Equals, Collection::idFullColumnName() );
   mItemQuery.addColumnCondition( Collection::resourceIdFullColumnName(), Query::Equals, Resource::idFullColumnName() );
-  addQueryConditions( mItemQuery );
+  ItemQueryHelper::scopeToQuery( mScope, connection(), mItemQuery );
   mItemQuery.addSortColumn( PimItem::idFullColumnName(), Query::Ascending );
 
   if ( !mItemQuery.exec() )
@@ -221,7 +223,7 @@ bool Fetch::parseStream()
     flagQuery.addColumn( Flag::nameFullColumnName() );
     flagQuery.addColumnCondition( PimItem::idFullColumnName(), Query::Equals, PimItemFlagRelation::leftFullColumnName() );
     flagQuery.addColumnCondition( Flag::idFullColumnName(), Query::Equals, PimItemFlagRelation::rightFullColumnName() );
-    addQueryConditions( flagQuery );
+    ItemQueryHelper::scopeToQuery( mScope, connection(), flagQuery );
     flagQuery.addSortColumn( PimItem::idFullColumnName(), Query::Ascending );
 
     if ( !flagQuery.exec() )
@@ -272,6 +274,7 @@ bool Fetch::parseStream()
     attributes.append( "REV " + QByteArray::number( pimItemRev ) );
     attributes.append( "REMOTEID " + ImapParser::quote( mItemQuery.query().value( itemQueryRidColumn ).toString().toUtf8() ) );
     attributes.append( "MIMETYPE " + ImapParser::quote( mItemQuery.query().value( itemQueryMimeTypeColumn ).toString().toUtf8() ) );
+    attributes.append( "COLLECTIONID " + ImapParser::quote( mItemQuery.query().value( itemQueryCollectionIdColumn ).toString().toUtf8() ) );
 
     if ( mSizeRequested ) {
       const qint64 pimItemSize = mItemQuery.query().value( itemQuerySizeColumn ).toLongLong();
@@ -349,9 +352,9 @@ bool Fetch::parseStream()
   // update atime
   updateItemAccessTime();
 
-  if ( mScope == Scope::Uid )
+  if ( mScope.scope() == Scope::Uid )
     successResponse( "UID FETCH completed" );
-  else if ( mScope == Scope::Rid )
+  else if ( mScope.scope() == Scope::Rid )
     successResponse( "RID FETCH completed" );
   else
     successResponse( "FETCH completed" );
@@ -362,16 +365,7 @@ bool Fetch::parseStream()
 void Fetch::parseCommandStream()
 {
   // sequence set
-  if ( mScope == Scope::None || mScope == Scope::Uid ) {
-    mSet = m_streamParser->readSequenceSet();
-    if ( mSet.isEmpty() )
-      throw HandlerException( "No items selected" );
-  } else if ( mScope == Scope::Rid ) {
-    mRid = m_streamParser->readUtf8String();
-    if ( mRid.isEmpty() )
-      throw HandlerException( "Empty remote identifier specified" );
-  } else
-    throw HandlerException( "WTF?!?" );
+  mScope.parseScope( m_streamParser );
 
   // macro vs. attribute list
   forever {
@@ -410,14 +404,3 @@ void Fetch::parseCommandStream()
   }
 }
 
-void Fetch::addQueryConditions(Akonadi::QueryBuilder& qb)
-{
-  if ( mScope == Scope::Uid || mScope == Scope::None )
-    ItemQueryHelper::itemSetToQuery( mSet, mScope == Scope::Uid, connection(), qb );
-  else if ( mScope == Scope::Rid )
-    ItemQueryHelper::remoteIdToQuery( mRid, connection(), qb );
-  else
-    throw HandlerException( "WTF?!?" );
-}
-
-
