@@ -155,11 +155,10 @@ bool Store::parseStream()
     if ( mPreviousRevision >= 0 && pimItems.at( i ).rev() != (int)mPreviousRevision )
       throw HandlerException( "Item was modified elsewhere, aborting STORE." );
     pimItems[ i ].setRev( pimItems[ i ].rev() + 1 );
-    pimItems[ i ].setDatetime( modificationtime );
-    pimItems[ i ].setAtime( modificationtime );
   }
 
   QSet<QByteArray> changes;
+  qint64 partSizes = 0;
 
   // apply modifications
   m_streamParser->beginList();
@@ -273,6 +272,7 @@ bool Store::parseStream()
       QByteArray value;
       if ( m_streamParser->hasLiteral() ) {
         const qint64 dataSize = m_streamParser->remainingLiteralSize();
+        partSizes += dataSize;
         const bool storeInFile = ( DbConfig::useExternalPayloadFile() && dataSize > DbConfig::sizeThreshold() );
         //actual case when streaming storage is used: external payload is enabled, data is big enough in a literal
         if ( storeInFile ) {
@@ -314,6 +314,7 @@ bool Store::parseStream()
         }
       } else { //not a literal
         value = m_streamParser->readString();
+        partSizes += value.size();
       }
 
       const QByteArray origData = PartHelper::translateData( part );
@@ -334,21 +335,32 @@ bool Store::parseStream()
     } // parts/attribute modification
   }
 
-  // run update query and prepare change notifications
-  for ( int i = 0; i < pimItems.count(); ++i ) {
-    PimItem item = pimItems[ i ];
-    if ( !connection()->isOwnerResource( item ) )
-      item.setDirty( true );
-    if ( !item.update() )
-      throw HandlerException( "Unable to write item changes into the database" );
-    store->notificationCollector()->itemChanged( item, changes );
+  QString datetime;
+  if ( !changes.isEmpty() ) {
+    // update item size
+    if ( pimItems.size() == 1 && (mSize > 0 || partSizes > 0) )
+      pimItems.first().setSize( qMax( mSize, partSizes ) );
+
+    // run update query and prepare change notifications
+    for ( int i = 0; i < pimItems.count(); ++i ) {
+      PimItem &item = pimItems[ i ];
+      item.setDatetime( modificationtime );
+      item.setAtime( modificationtime );
+      if ( !connection()->isOwnerResource( item ) )
+        item.setDirty( true );
+      if ( !item.update() )
+        throw HandlerException( "Unable to write item changes into the database" );
+      store->notificationCollector()->itemChanged( item, changes );
+    }
+
+    if ( !transaction.commit() )
+      return failureResponse( "Cannot commit transaction." );
+
+    datetime = QLocale::c().toString( modificationtime, QLatin1String( "dd-MMM-yyyy hh:mm:ss +0000" ) );
+  } else {
+    datetime = QLocale::c().toString( pimItems.first().datetime(), QLatin1String( "dd-MMM-yyyy hh:mm:ss +0000" ) );
   }
 
-  if ( !transaction.commit() )
-    return failureResponse( "Cannot commit transaction." );
-
-  const QString datetime = QLocale::c().toString( modificationtime, QLatin1String( "dd-MMM-yyyy hh:mm:ss +0000" ) );
-
   Response response;
   response.setTag( tag() );
   response.setSuccess();
