@@ -69,11 +69,19 @@ class HandlerHelper
     */
     static int itemWithoutFlagCount( const Collection &col, const QString &flag );
 
+    /**
+      Returns the total size of all the items in the given collection.
+      @return -1 on error
+     */
+    static qint64 itemsTotalSize( const Collection &col );
+
     /**
       Parse cache policy and update the given Collection object accoordingly.
+      @param changed Indicates wether or not the cache policy already available in @p col
+      has actually changed
       @todo Error handling.
     */
-    static int parseCachePolicy( const QByteArray &data, Collection &col, int start = 0 );
+    static int parseCachePolicy( const QByteArray& data, Akonadi::Collection& col, int start = 0, bool* changed = 0 );
 
     /**
       Returns the protocol representation of the cache policy of the given
@@ -86,7 +94,7 @@ class HandlerHelper
       Make sure DataStore::activeCachePolicy() has been called before to include
       the effective cache policy
     */
-    static QByteArray collectionToByteArray( const Collection &col, bool hidden = false );
+    static QByteArray collectionToByteArray( const Collection &col, bool hidden = false, bool includeStatistics = false );
 };
 
 }
